@@ -219,6 +219,10 @@ class Device(NestBase):
     def name_long(self):
         return self._device.get('name_long')
 
+    @property
+    def device_id(self):
+        return self._device.get('device_id')
+
     @property
     def online(self):
         return self._device.get('is_online')
@@ -397,6 +401,10 @@ class Thermostat(Device):
     def is_using_emergency_heat(self):
         return self._device.get('is_using_emergency_heat')
 
+    @property
+    def label(self):
+        return self._device.get('label')
+
     @property
     def local_ip(self):
         raise NotImplementedError("No longer available in Nest API")
